@@ -1,8 +1,10 @@
 #include "tests.h"
+
 #ifdef HAVE_SIGNALFD
-static void sig_usr1(int signo){
+static void sig_usr1(int signo ){
 
 }
+
 TEST(os_signal, swSignalfd_set)
 {
     int ret;
@@ -10,6 +12,9 @@ TEST(os_signal, swSignalfd_set)
 
     SwooleG.use_signalfd = 1;
 
+    swoole_event_init();
+    SwooleTG.reactor->wait_exit = 1;
+
     sigemptyset(&curset);
     sigprocmask(SIG_BLOCK, NULL, &curset);
     ret = sigismember(&curset,SIGUSR1);
@@ -17,19 +22,21 @@ TEST(os_signal, swSignalfd_set)
 
     swSignalfd_init();
     swSignal_add(SIGUSR1,sig_usr1);
-    swSignalfd_setup(SwooleG.main_reactor);
+    swSignalfd_setup(SwooleTG.reactor);
 
     sigemptyset(&curset);
     sigprocmask(SIG_BLOCK, NULL, &curset);
     ret = sigismember(&curset,SIGUSR1);
     ASSERT_EQ(ret, 1);
 
-    swSignal_add(SIGUSR1,NULL);
+    swSignal_add(SIGUSR1, NULL);
     swSignal_clear();
 
     sigemptyset(&curset);
     sigprocmask(SIG_BLOCK, NULL, &curset);
     ret = sigismember(&curset,SIGUSR1);
     ASSERT_EQ(ret, 0);
+
+    swoole_event_wait();
 }
 #endif
