@@ -49,12 +49,6 @@ typedef enum
 typedef void (*sw_coro_on_swap_t)(void*);
 typedef void (*sw_coro_bailout_t)();
 
-#ifdef SW_CO_MT
-#define sw_co_thread_local   thread_local
-#else
-#define sw_co_thread_local
-#endif
-
 namespace swoole
 {
 struct socket_poll_fd
@@ -115,7 +109,7 @@ public:
         task = _task;
     }
 
-    static sw_co_thread_local std::unordered_map<long, Coroutine*> coroutines;
+    static std::unordered_map<long, Coroutine*> coroutines;
 
     static void set_on_yield(sw_coro_on_swap_t func);
     static void set_on_resume(sw_coro_on_swap_t func);
@@ -191,9 +185,9 @@ public:
     static void print_list();
 
 protected:
-    static sw_co_thread_local Coroutine* current;
-    static sw_co_thread_local long last_cid;
-    static sw_co_thread_local uint64_t peak_num;
+    static Coroutine* current;
+    static long last_cid;
+    static uint64_t peak_num;
     static size_t stack_size;
     static sw_coro_on_swap_t on_yield;   /* before yield */
     static sw_coro_on_swap_t on_resume;  /* before resume */
