@@ -97,20 +97,6 @@ extern zend_module_entry swoole_module_entry;
 #define ifr_hwaddr ifr_addr
 #endif
 
-#define SWOOLE_PROPERTY_MAX     32
-#define SWOOLE_OBJECT_DEFAULT   65536
-#define SWOOLE_OBJECT_MAX       10000000
-
-typedef struct
-{
-    void **array;
-    uint32_t size;
-    void **property[SWOOLE_PROPERTY_MAX];
-    uint32_t property_size[SWOOLE_PROPERTY_MAX];
-} swoole_object_array;
-
-extern swoole_object_array swoole_objects;
-
 #define SW_CHECK_RETURN(s)      if(s<0){RETURN_FALSE;}else{RETURN_TRUE;}
 #define SW_LOCK_CHECK_RETURN(s) if(s==0){RETURN_TRUE;}else{zend_update_property_long(NULL,ZEND_THIS,SW_STRL("errCode"),s);RETURN_FALSE;}
 
@@ -196,7 +182,7 @@ typedef struct
     swServer *serv;
     swListenPort *port;
     zval *zsetting;
-} swoole_server_port_property;
+} php_swoole_server_port_property;
 //---------------------------------------------------------
 #define SW_FLAG_KEEP                        (1u << 12)
 #define SW_FLAG_ASYNC                       (1u << 10)
@@ -251,6 +237,7 @@ extern zend_class_entry *swoole_process_ce;
 extern zend_class_entry *swoole_http_server_ce;
 extern zend_object_handlers swoole_http_server_handlers;
 extern zend_class_entry *swoole_websocket_server_ce;
+extern zend_class_entry *swoole_websocket_frame_ce;
 extern zend_class_entry *swoole_server_port_ce;
 extern zend_class_entry *swoole_exception_ce;
 extern zend_object_handlers swoole_exception_handlers;
@@ -369,8 +356,25 @@ void php_swoole_client_check_setting(swClient *cli, zval *zset);
 #ifdef SW_USE_OPENSSL
 void php_swoole_client_check_ssl_setting(swClient *cli, zval *zset);
 #endif
+
+static sw_inline zend_bool php_swoole_websocket_frame_is_object(zval *zdata)
+{
+    return Z_TYPE_P(zdata) == IS_OBJECT && instanceof_function(Z_OBJCE_P(zdata), swoole_websocket_frame_ce);
+}
+
+#ifdef SW_HAVE_ZLIB
+#define php_swoole_websocket_frame_pack        php_swoole_websocket_frame_pack_ex
+#define php_swoole_websocket_frame_object_pack php_swoole_websocket_frame_object_pack_ex
+#else
+#define php_swoole_websocket_frame_pack(buffer, zdata, opcode, flags, mask, allow_compress) \
+        php_swoole_websocket_frame_pack_ex(buffer, zdata, opcode, flags, mask, 0)
+#define php_swoole_websocket_frame_object_pack(buffer, zdata, mask, allow_compress) \
+        php_swoole_websocket_frame_object_pack_ex(buffer, zdata, mask, 0)
+#endif
+int php_swoole_websocket_frame_pack_ex(swString *buffer, zval *zdata, zend_long opcode, uint8_t flags, zend_bool mask, zend_bool allow_compress);
+int php_swoole_websocket_frame_object_pack_ex(swString *buffer, zval *zdata, zend_bool mask, zend_bool allow_compress);
 void php_swoole_websocket_frame_unpack(swString *data, zval *zframe);
-int php_swoole_websocket_frame_pack(swString *buffer, zval *zdata, zend_bool opcode, zend_bool fin, zend_bool mask);
+void php_swoole_websocket_frame_unpack_ex(swString *data, zval *zframe, uchar allow_uncompress);
 
 int php_swoole_task_pack(swEventData *task, zval *data);
 zval* php_swoole_task_unpack(swEventData *task_result);
@@ -379,44 +383,6 @@ zval* php_swoole_task_unpack(swEventData *task_result);
 int php_swoole_zlib_decompress(z_stream *stream, swString *buffer, char *body, int length);
 #endif
 
-static sw_inline void* swoole_get_object_by_handle(uint32_t handle)
-{
-    assert(handle < swoole_objects.size);
-    return swoole_objects.array[handle];
-}
-
-static sw_inline void* swoole_get_property_by_handle(uint32_t handle, int property_id)
-{
-    if (sw_unlikely(handle >= swoole_objects.property_size[property_id]))
-    {
-        return NULL;
-    }
-    return swoole_objects.property[property_id][handle];
-}
-
-static sw_inline void* swoole_get_object(zval *zobject)
-{
-    return swoole_get_object_by_handle(Z_OBJ_HANDLE_P(zobject));
-}
-
-static sw_inline void* swoole_get_property(zval *zobject, int property_id)
-{
-    return swoole_get_property_by_handle(Z_OBJ_HANDLE_P(zobject), property_id);
-}
-
-void swoole_set_object_by_handle(uint32_t handle, void *ptr);
-void swoole_set_property_by_handle(uint32_t handle, int property_id, void *ptr);
-
-static sw_inline void swoole_set_object(zval *zobject, void *ptr)
-{
-    swoole_set_object_by_handle(Z_OBJ_HANDLE_P(zobject), ptr);
-}
-
-static sw_inline void swoole_set_property(zval *zobject, int property_id, void *ptr)
-{
-    swoole_set_property_by_handle(Z_OBJ_HANDLE_P(zobject), property_id, ptr);
-}
-
 int swoole_convert_to_fd(zval *zsocket);
 int swoole_convert_to_fd_ex(zval *zsocket, int *async);
 
