@@ -645,7 +645,11 @@ Socket::Socket(int _fd, swSocketAddress *addr, Socket *server_sock)
     open_eof_check = server_sock->open_eof_check;
     http2 = server_sock->http2;
     protocol = server_sock->protocol;
-    memcpy(&socket->info.addr, &addr, addr->len);
+
+    socket->socket_type = server_sock->socket->socket_type;
+    memcpy(&socket->info.addr, addr, addr->len);
+    socket->info.len = addr->len;
+
 #ifdef SW_USE_OPENSSL
     if (server_sock->open_ssl)
     {
@@ -658,10 +662,10 @@ Socket::Socket(int _fd, swSocketAddress *addr, Socket *server_sock)
 #endif
 }
 
-bool Socket::getsockname()
+bool Socket::getsockname(swSocketAddress *sa)
 {
-    socket->info.len = sizeof(socket->info.addr);
-    if (::getsockname(sock_fd, (struct sockaddr *) &socket->info.addr, &socket->info.len) != 0)
+    sa->len = sizeof(sa->addr);
+    if (::getsockname(sock_fd, (struct sockaddr *) &sa->addr, &sa->len) != 0)
     {
         set_err(errno);
         return false;
@@ -669,10 +673,10 @@ bool Socket::getsockname()
     return true;
 }
 
-bool Socket::getpeername()
+bool Socket::getpeername(swSocketAddress *sa)
 {
-    socket->info.len = sizeof(socket->info.addr);
-    if (::getpeername(sock_fd, (struct sockaddr *) &socket->info.addr, &socket->info.len) != 0)
+    sa->len = sizeof(sa->addr);
+    if (::getpeername(sock_fd, (struct sockaddr *) &sa->addr, &sa->len) != 0)
     {
         set_err(errno);
         return false;
@@ -1415,7 +1419,16 @@ bool Socket::ssl_accept()
     do {
         retval = swSSL_accept(socket);
     } while (retval == SW_WAIT && timer.start() && wait_event(SW_EVENT_READ));
-    return retval == SW_READY;
+
+    if (retval != SW_READY)
+    {
+        set_err(SW_ERROR_SSL_BAD_CLIENT);
+        return false;
+    }
+    else
+    {
+        return true;
+    }
 }
 
 int Socket::ssl_verify(bool allow_self_signed)
@@ -1518,7 +1531,7 @@ ssize_t Socket::sendto(const char *address, int port, const void *__buf, size_t
         struct sockaddr_in in;
         struct sockaddr_in6 in6;
         struct sockaddr_un un;
-    } addr = { { 0 } };
+    } addr = {};
     size_t addr_size = 0;
 
     switch (type)
@@ -1632,7 +1645,10 @@ ssize_t Socket::recv_packet(double timeout)
         uint32_t header_len = protocol.package_length_offset + protocol.package_length_size;
         if (read_buffer->length > 0)
         {
-            if (read_buffer->length >= header_len || protocol.package_length_type == '\0')
+            if (
+                read_buffer->length >= header_len ||
+                (protocol.package_length_size == 0 && protocol.package_length_type == '\0') // custom package_length_func
+            )
             {
                 goto _get_length;
             }
@@ -1654,17 +1670,20 @@ ssize_t Socket::recv_packet(double timeout)
         }
 
         _get_length:
+        protocol.real_header_length = 0;
         buf_len = protocol.get_package_length(&protocol, socket, read_buffer->str, (uint32_t) read_buffer->length);
         swTraceLog(SW_TRACE_SOCKET, "packet_len=%ld, length=%ld", buf_len, read_buffer->length);
-        //error package
         if (buf_len < 0)
         {
-            set_err(SW_ERROR_PACKAGE_LENGTH_NOT_FOUND, "package length is wrong (negative)");
+            set_err(SW_ERROR_PACKAGE_LENGTH_NOT_FOUND, "get package length failed");
             return 0;
         }
         else if (buf_len == 0)
         {
-            header_len = protocol.real_header_length;
+            if (protocol.real_header_length != 0)
+            {
+                header_len = protocol.real_header_length;
+            }
             goto _recv_header;
         }
         else if (buf_len > protocol.package_max_length)
@@ -2000,7 +2019,7 @@ Socket::~Socket()
     {
         sw_free(ssl_option.capath);
     }
-    ssl_option = {0};
+    ssl_option = {};
 #endif
     if (socket->in_buffer)
     {
@@ -2013,7 +2032,7 @@ Socket::~Socket()
     if (sock_domain == AF_UNIX && !bind_address.empty())
     {
         ::unlink(bind_address_info.addr.un.sun_path);
-        bind_address_info = {{}, 0};
+        bind_address_info = {};
     }
     if (sock_type == SW_SOCK_UNIX_DGRAM)
     {
