@@ -19,6 +19,10 @@
 
 #ifdef SW_USE_OPENSSL
 
+#if OPENSSL_VERSION_NUMBER < 0x10000000L
+#error "require openssl version 1.0 or later"
+#endif
+
 #include <openssl/crypto.h>
 #include <openssl/x509.h>
 #include <openssl/x509v3.h>
@@ -35,8 +39,8 @@ static RSA* swSSL_rsa_key_callback(SSL *ssl, int is_export, int key_length);
 #if OPENSSL_VERSION_NUMBER < 0x10100000L
 static int swSSL_set_default_dhparam(SSL_CTX* ssl_context);
 #endif
-static int swSSL_set_dhparam(SSL_CTX* ssl_context, char *file);
-static int swSSL_set_ecdh_curve(SSL_CTX* ssl_context);
+static int swSSL_set_dhparam(SSL_CTX* ssl_context, const char *file);
+static int swSSL_set_ecdh_curve(SSL_CTX* ssl_context, const char *ecdh_curve);
 
 #ifdef TLSEXT_TYPE_next_proto_neg
 static int swSSL_npn_advertised(SSL *ssl, const uchar **out, uint32_t *outlen, void *arg);
@@ -52,7 +56,7 @@ static int swSSL_alpn_advertised(SSL *ssl, const uchar **out, uchar *outlen, con
     #define MAYBE_UNUSED
 #endif
 
-static void MAYBE_UNUSED swSSL_lock_callback(int mode, int type, char *file, int line);
+static void MAYBE_UNUSED swSSL_lock_callback(int mode, int type, const char *file, int line);
 
 static const SSL_METHOD *swSSL_get_method(int method)
 {
@@ -157,7 +161,7 @@ void swSSL_destroy()
     CRYPTO_set_locking_callback(NULL);
 }
 
-static void MAYBE_UNUSED swSSL_lock_callback(int mode, int type, char *file, int line)
+static void MAYBE_UNUSED swSSL_lock_callback(int mode, int type, const char *file, int line)
 {
     if (mode & CRYPTO_LOCK)
     {
@@ -207,7 +211,7 @@ void swSSL_init_thread_safety()
     CRYPTO_set_id_callback(swSSL_id_callback);
 #endif
 
-    CRYPTO_set_locking_callback((void (*)()) swSSL_lock_callback);
+    CRYPTO_set_locking_callback(swSSL_lock_callback);
 }
 
 void swSSL_server_http_advise(SSL_CTX* ssl_context, swSSL_config *cfg)
@@ -263,7 +267,7 @@ int swSSL_server_set_cipher(SSL_CTX* ssl_context, swSSL_config *cfg)
 #endif
     if (cfg->ecdh_curve && strlen(cfg->ecdh_curve) > 0)
     {
-        swSSL_set_ecdh_curve(ssl_context);
+        swSSL_set_ecdh_curve(ssl_context, cfg->ecdh_curve);
     }
     return SW_OK;
 }
@@ -625,7 +629,7 @@ int swSSL_check_host(swSocket *conn, char *tls_host_name)
      * As per RFC6125 and RFC2818, we check subjectAltName extension,
      * and if it's not present - commonName in Subject is checked.
      */
-    altnames = X509_get_ext_d2i(cert, NID_subject_alt_name, NULL, NULL);
+    altnames = (STACK_OF(GENERAL_NAME) *) X509_get_ext_d2i(cert, NID_subject_alt_name, NULL, NULL);
 
     if (altnames)
     {
@@ -826,8 +830,13 @@ int swSSL_accept(swSocket *conn)
     else if (err == SSL_ERROR_SSL)
     {
         int reason = ERR_GET_REASON(ERR_peek_error());
-        swWarn("bad SSL client[%s:%d], reason=%d", swConnection_get_ip(conn->socket_type, &conn->info),
-                swConnection_get_port(conn->socket_type, &conn->info), reason);
+        const char *error_string = ERR_error_string(reason, SwooleTG.buffer_stack->str);
+        swWarn(
+            "bad SSL client[%s:%d], reason=%d, error_string=%s",
+            swConnection_get_ip(conn->socket_type, &conn->info),
+            swConnection_get_port(conn->socket_type, &conn->info),
+            reason, error_string
+        );
         return SW_ERROR;
     }
     //EOF was observed
@@ -1220,9 +1229,8 @@ static int swSSL_set_default_dhparam(SSL_CTX* ssl_context)
 }
 #endif
 
-static int swSSL_set_ecdh_curve(SSL_CTX* ssl_context)
+static int swSSL_set_ecdh_curve(SSL_CTX* ssl_context, const char *ecdh_curve)
 {
-#if OPENSSL_VERSION_NUMBER >= 0x0090800fL
 #ifndef OPENSSL_NO_ECDH
 
     EC_KEY *ecdh;
@@ -1232,17 +1240,17 @@ static int swSSL_set_ecdh_curve(SSL_CTX* ssl_context)
      * binary fields. OpenSSL only supports the "named curves", which provide
      * maximum interoperability.
      */
-    int nid = OBJ_sn2nid(SW_SSL_ECDH_CURVE);
+    int nid = OBJ_sn2nid(ecdh_curve);
     if (nid == 0)
     {
-        swWarn("Unknown curve name \"%s\"", SW_SSL_ECDH_CURVE);
+        swWarn("Unknown curve name \"%s\"", ecdh_curve);
         return SW_ERR;
     }
 
     ecdh = EC_KEY_new_by_curve_name(nid);
     if (ecdh == NULL)
     {
-        swWarn("Unable to create curve \"%s\"", SW_SSL_ECDH_CURVE);
+        swWarn("Unable to create curve \"%s\"", ecdh_curve);
         return SW_ERR;
     }
 
@@ -1250,13 +1258,12 @@ static int swSSL_set_ecdh_curve(SSL_CTX* ssl_context)
     SSL_CTX_set_tmp_ecdh(ssl_context, ecdh);
 
     EC_KEY_free(ecdh);
-#endif
 #endif
 
     return SW_OK;
 }
 
-static int swSSL_set_dhparam(SSL_CTX* ssl_context, char *file)
+static int swSSL_set_dhparam(SSL_CTX* ssl_context, const char *file)
 {
     DH *dh;
     BIO *bio;
