@@ -223,10 +223,12 @@ int swReactor_close(swReactor *reactor, int fd)
     if (socket->out_buffer)
     {
         swBuffer_free(socket->out_buffer);
+        socket->out_buffer = NULL;
     }
     if (socket->in_buffer)
     {
         swBuffer_free(socket->in_buffer);
+        socket->in_buffer = NULL;
     }
 
     bzero(socket, sizeof(swSocket));
@@ -432,17 +434,11 @@ void swReactor_add_destroy_callback(swReactor *reactor, swCallback cb, void *dat
     cm->append(cb, data);
 }
 
-void swReactor_defer_task_destroy(swReactor *reactor)
-{
-    CallbackManager *tasks = (CallbackManager *) reactor->defer_tasks;
-    delete tasks;
-}
-
 static void defer_task_do(swReactor *reactor)
 {
     CallbackManager *cm = (CallbackManager *) reactor->defer_tasks;
-    cm->execute();
     reactor->defer_tasks = nullptr;
+    cm->execute();
     delete cm;
 }
 
