@@ -14,7 +14,6 @@
  +----------------------------------------------------------------------+
  */
 
-#include "swoole.h"
 #include "server.h"
 
 static int swFactory_start(swFactory *factory);
@@ -51,8 +50,7 @@ static int swFactory_shutdown(swFactory *factory)
 static int swFactory_dispatch(swFactory *factory, swSendData *task)
 {
     swServer *serv = factory->ptr;
-    factory->last_from_id = task->info.from_id;
-    swPackagePtr pkg;
+    swPacket_ptr pkg;
 
     if (swEventData_is_stream(task->info.type))
     {
@@ -71,7 +69,7 @@ static int swFactory_dispatch(swFactory *factory, swSendData *task)
         }
         //converted fd to session_id
         task->info.fd = conn->session_id;
-        task->info.from_fd = conn->from_fd;
+        task->info.server_fd = conn->server_fd;
     }
     //with data
     if (task->info.len > 0)
@@ -111,7 +109,7 @@ static int swFactory_notify(swFactory *factory, swDataHead *info)
     }
     //converted fd to session_id
     info->fd = conn->session_id;
-    info->from_fd = conn->from_fd;
+    info->server_fd = conn->server_fd;
     info->flags = SW_EVENT_DATA_NORMAL;
     return swWorker_onTask(factory, (swEventData *) info);
 }
@@ -125,7 +123,7 @@ static int swFactory_end(swFactory *factory, int fd)
     bzero(&_send, sizeof(_send));
     _send.info.fd = fd;
     _send.info.len = 0;
-    _send.info.type = SW_EVENT_CLOSE;
+    _send.info.type = SW_SERVER_EVENT_CLOSE;
 
     swConnection *conn = swWorker_get_connection(serv, fd);
     if (conn == NULL || conn->active == 0)
@@ -135,7 +133,7 @@ static int swFactory_end(swFactory *factory, int fd)
     }
     else if (conn->close_force)
     {
-        goto do_close;
+        goto _do_close;
     }
     else if (conn->closing)
     {
@@ -148,34 +146,34 @@ static int swFactory_end(swFactory *factory, int fd)
     }
     else
     {
-        do_close:
+        _do_close:
         conn->closing = 1;
         if (serv->onClose != NULL)
         {
             info.fd = fd;
             if (conn->close_actively)
             {
-                info.from_id = -1;
+                info.reactor_id = -1;
             }
             else
             {
-                info.from_id = conn->from_id;
+                info.reactor_id = conn->reactor_id;
             }
-            info.from_fd = conn->from_fd;
+            info.server_fd = conn->server_fd;
             serv->onClose(serv, &info);
         }
         conn->closing = 0;
         conn->closed = 1;
         conn->close_errno = 0;
 
-        if (swBuffer_empty(conn->out_buffer) || conn->removed)
+        if (swBuffer_empty(conn->socket->out_buffer) || conn->peer_closed)
         {
-            swReactor *reactor = SwooleG.main_reactor;
+            swReactor *reactor = SwooleTG.reactor;
             return swReactorThread_close(reactor, conn->fd);
         }
         else
         {
-            swBuffer_chunk *chunk = swBuffer_new_chunk(conn->out_buffer, SW_CHUNK_CLOSE, 0);
+            swBuffer_chunk *chunk = swBuffer_new_chunk(conn->socket->out_buffer, SW_CHUNK_CLOSE, 0);
             chunk->store.data.val1 = _send.info.type;
             conn->close_queued = 1;
             return SW_OK;
