@@ -130,7 +130,8 @@ int swServer_master_onAccept(swReactor *reactor, swEvent *event)
 
         //add to connection_list
         swConnection *conn = swServer_connection_new(serv, listen_host, new_fd, event->fd);
-        memcpy(&conn->info.addr, &event->socket->info, sizeof(event->socket->info));
+        memcpy(&conn->info.addr, &event->socket->info.addr, event->socket->info.len);
+        conn->info.len = event->socket->info.len;
         conn->socket_type = listen_host->type;
 
 #ifdef SW_USE_OPENSSL
@@ -145,6 +146,9 @@ int swServer_master_onAccept(swReactor *reactor, swEvent *event)
             else
             {
                 conn->ssl = 1;
+                memcpy(&_socket->info.addr, &conn->info.addr, conn->info.len);
+                _socket->info.len = conn->info.len;
+                _socket->socket_type = conn->socket_type;
             }
         }
         else
@@ -162,7 +166,7 @@ int swServer_master_onAccept(swReactor *reactor, swEvent *event)
         }
         else
         {
-            swDataHead ev = {0};
+            swDataHead ev = {};
             ev.type = SW_SERVER_EVENT_INCOMING;
             ev.fd = new_fd;
             int _pipe_fd = swServer_get_send_pipe(serv, conn->session_id, conn->reactor_id);
@@ -729,8 +733,8 @@ void swServer_init(swServer *serv)
     serv->http_parse_post = 1;
 #ifdef SW_HAVE_COMPRESSION
     serv->http_compression = 1;
-#endif
     serv->http_compression_level = SW_Z_BEST_SPEED;
+#endif
     serv->upload_tmp_dir = sw_strdup("/tmp");
 
     serv->buffer_input_size = SW_BUFFER_INPUT_SIZE;
@@ -1217,7 +1221,7 @@ int swServer_master_send(swServer *serv, swSendData *_send)
  */
 static int swServer_tcp_notify(swServer *serv, swConnection *conn, int event)
 {
-    swDataHead notify_event = {0};
+    swDataHead notify_event = {};
     notify_event.type = event;
     notify_event.reactor_id = conn->reactor_id;
     notify_event.fd = conn->fd;
@@ -1275,7 +1279,7 @@ static int swServer_tcp_sendfile(swServer *serv, int session_id, const char *fil
     req->length = length;
 
     // construct send data
-    swSendData send_data = {{0}};
+    swSendData send_data = {};
     send_data.info.fd = session_id;
     send_data.info.type = SW_SERVER_EVENT_SEND_FILE;
     send_data.info.len = sizeof(swSendFile_request) + l_file + 1;
@@ -1338,7 +1342,7 @@ static int swServer_tcp_close(swServer *serv, int session_id, int reset)
 
     int retval;
     swWorker *worker;
-    swDataHead ev = { 0 };
+    swDataHead ev = {};
 
     if (swServer_dispatch_mode_is_mod(serv))
     {
@@ -1663,7 +1667,6 @@ swListenPort* swServer_add_port(swServer *serv, enum swSocket_type type, const c
             ls->ssl_config.stapling = 1;
             ls->ssl_config.stapling_verify = 1;
             ls->ssl_config.ciphers = sw_strdup(SW_SSL_CIPHER_LIST);
-            ls->ssl_config.ecdh_curve = sw_strdup(SW_SSL_ECDH_CURVE);
 #endif
         }
     }
