@@ -1248,7 +1248,7 @@ void swReactorThread_join(swServer *serv)
         thread = &(serv->reactor_threads[i]);
         if (thread->notify_pipe)
         {
-            swDataHead ev = {0};
+            swDataHead ev = {};
             ev.type = SW_SERVER_EVENT_SHUTDOWN;
             if (swSocket_write_blocking(thread->notify_pipe, (void *) &ev, sizeof(ev)) < 0)
             {
@@ -1301,7 +1301,6 @@ static void swHeartbeatThread_loop(swThreadParam *param)
     swSignal_none();
 
     swServer *serv = (swServer *) param->object;
-    swConnection *conn;
     swReactor *reactor;
 
     int fd;
@@ -1322,9 +1321,8 @@ static void swHeartbeatThread_loop(swThreadParam *param)
         for (fd = serv_min_fd; fd <= serv_max_fd; fd++)
         {
             swTrace("check fd=%d", fd);
-            conn = swServer_connection_get(serv, fd);
-
-            if (conn && conn->socket && conn->active == 1 && conn->closed == 0 && conn->socket->fdtype == SW_FD_SESSION)
+            swConnection *conn = swServer_connection_get(serv, fd);
+            if (swServer_connection_valid(serv, conn))
             {
                 if (conn->protect || conn->last_time > checktime)
                 {
