@@ -648,8 +648,11 @@ PHP_MINFO_FUNCTION(swoole)
 PHP_RINIT_FUNCTION(swoole)
 {
     SWOOLE_G(req_status) = PHP_SWOOLE_RINIT_BEGIN;
+
     SwooleG.running = 1;
+
     php_swoole_register_shutdown_function("swoole_internal_call_user_shutdown_begin");
+
     if (
         SWOOLE_G(enable_library) && SWOOLE_G(cli)
 #ifdef ZEND_COMPILE_PRELOAD
@@ -660,7 +663,14 @@ PHP_RINIT_FUNCTION(swoole)
     {
         php_swoole_load_library();
     }
+
+#ifdef ZEND_SIGNALS
+    /* Disable warning even in ZEND_DEBUG because we may register our own signal handlers  */
+    SIGG(check) = 0;
+#endif
+
     SWOOLE_G(req_status) = PHP_SWOOLE_RINIT_END;
+
     return SUCCESS;
 }
 
@@ -725,6 +735,7 @@ static PHP_FUNCTION(swoole_hashcode)
     {
     case 1:
         RETURN_LONG(hashkit_one_at_a_time(data, l_data));
+        break; /* ide */
     default:
         RETURN_LONG(zend_hash_func(data, l_data));
     }
@@ -759,7 +770,7 @@ PHP_FUNCTION(swoole_strerror)
     {
         RETURN_STRING(hstrerror(swoole_errno));
     }
-    else if (error_type == SW_STRERROR_SWOOLE || (swoole_errno > SW_ERROR_START && swoole_errno < SW_ERROR_END))
+    else if (error_type == SW_STRERROR_SWOOLE || (swoole_errno > SW_ERROR_BEGIN && swoole_errno < SW_ERROR_END))
     {
         RETURN_STRING(swoole_strerror(swoole_errno));
     }
@@ -853,7 +864,7 @@ PHP_FUNCTION(swoole_get_local_mac)
 #ifdef SIOCGIFHWADDR
     struct ifconf ifc;
     struct ifreq buf[16];
-    char mac[32] = {0};
+    char mac[32] = {};
 
     int sock;
     int i = 0,num = 0;
