@@ -221,7 +221,7 @@ static Socket* client_coro_new(zval *zobject, int port)
     {
         php_swoole_sys_error(E_WARNING, "new Socket() failed");
         zend_update_property_long(Z_OBJCE_P(zobject), zobject, ZEND_STRL("errCode"), errno);
-        zend_update_property_string(Z_OBJCE_P(zobject), zobject, ZEND_STRL("errMsg"), strerror(errno));
+        zend_update_property_string(Z_OBJCE_P(zobject), zobject, ZEND_STRL("errMsg"), swoole_strerror(errno));
         delete cli;
         return NULL;
     }
@@ -361,7 +361,7 @@ bool php_swoole_client_set(Socket *cli, zval *zset)
          */
         if (php_swoole_array_get_value(vht, "bind_address", ztmp))
         {
-            if (swSocket_bind(cli->get_fd(), cli->get_type(), zend::string(ztmp).val(), &bind_port) != SW_OK)
+            if (!cli->bind(zend::string(ztmp).val(), bind_port))
             {
                 ret = false;
             }
@@ -981,7 +981,8 @@ static PHP_METHOD(swoole_client_coro, getsockname)
         RETURN_FALSE;
     }
 
-    if (!cli->getsockname())
+    swSocketAddress sa;
+    if (!cli->getsockname(&sa))
     {
         zend_update_property_long(swoole_client_coro_ce, ZEND_THIS, ZEND_STRL("errCode"), cli->errCode);
         zend_update_property_string(swoole_client_coro_ce, ZEND_THIS, ZEND_STRL("errMsg"), cli->errMsg);
@@ -989,8 +990,8 @@ static PHP_METHOD(swoole_client_coro, getsockname)
     }
 
     array_init(return_value);
-    add_assoc_string(return_value, "host", (char *) cli->get_ip());
-    add_assoc_long(return_value, "port", cli->get_port());
+    add_assoc_string(return_value, "host", (char *) swConnection_get_ip(cli->get_type(), &sa));
+    add_assoc_long(return_value, "port", swConnection_get_port(cli->get_type(), &sa));
 }
 
 /**
@@ -1025,7 +1026,8 @@ static PHP_METHOD(swoole_client_coro, getpeername)
         RETURN_FALSE;
     }
 
-    if (!cli->getsockname())
+    swSocketAddress sa;
+    if (!cli->getpeername(&sa))
     {
         zend_update_property_long(swoole_client_coro_ce, ZEND_THIS, ZEND_STRL("errCode"), cli->errCode);
         zend_update_property_string(swoole_client_coro_ce, ZEND_THIS, ZEND_STRL("errMsg"), cli->errMsg);
@@ -1033,8 +1035,8 @@ static PHP_METHOD(swoole_client_coro, getpeername)
     }
 
     array_init(return_value);
-    add_assoc_string(return_value, "host", (char *) cli->get_ip());
-    add_assoc_long(return_value, "port", cli->get_port());
+    add_assoc_string(return_value, "host", (char *) swConnection_get_ip(cli->get_type(), &sa));
+    add_assoc_long(return_value, "port", swConnection_get_port(cli->get_type(), &sa));
 }
 
 static PHP_METHOD(swoole_client_coro, close)
