@@ -140,12 +140,40 @@ public:
         RETURN_STRINGL(buffer->str, offset);
     }
 
+    void getsockname(zval *return_value)
+    {
+        swSocketAddress sa;
+        if (!socket || !socket->getsockname(&sa))
+        {
+            ZVAL_FALSE(return_value);
+            return;
+        }
+
+        array_init(return_value);
+        add_assoc_string(return_value, "host", (char *) swConnection_get_ip(socket->get_type(), &sa));
+        add_assoc_long(return_value, "port", swConnection_get_port(socket->get_type(), &sa));
+    }
+
+    void getpeername(zval *return_value)
+    {
+        swSocketAddress sa;
+        if (!socket || !socket->getpeername(&sa))
+        {
+            ZVAL_FALSE(return_value);
+            return;
+        }
+
+        array_init(return_value);
+        add_assoc_string(return_value, "host", (char *) swConnection_get_ip(socket->get_type(), &sa));
+        add_assoc_long(return_value, "port", swConnection_get_port(socket->get_type(), &sa));
+    }
+
     ~http_client();
 
 private:
     Socket* socket = nullptr;
     swSocket_type socket_type = SW_SOCK_TCP;
-    swoole_http_parser parser = {0};
+    swoole_http_parser parser = {};
     bool wait = false;
 };
 
@@ -429,12 +457,6 @@ static int http_parser_on_header_value(swoole_http_parser *parser, const char *a
 static int http_parser_on_headers_complete(swoole_http_parser *parser)
 {
     http_client* http = (http_client*) parser->data;
-    //no content-length
-    if (http->chunked == 0 && parser->content_length == -1)
-    {
-        enum flags { F_CONNECTION_CLOSE = 1 << 2 };
-        parser->flags |= F_CONNECTION_CLOSE;
-    }
     if (http->method == SW_HTTP_HEAD || parser->status_code == SW_HTTP_NO_CONTENT)
     {
         return 1;
@@ -1291,7 +1313,7 @@ bool http_client::send()
             http_client_swString_append_headers(buffer, ZEND_STRL("Content-Type"), ZEND_STRL("application/x-www-form-urlencoded"));
             if (php_swoole_array_length(zbody) > 0)
             {
-                smart_str formstr_s = { 0 };
+                smart_str formstr_s = {};
                 char *formstr = php_swoole_http_build_query(zbody, &len, &formstr_s);
                 if (formstr == NULL)
                 {
@@ -1393,8 +1415,10 @@ bool http_client::recv(double timeout)
     if (websocket)
     {
         socket->open_length_check = 1;
-        socket->protocol.get_package_length = swWebSocket_get_package_length;
         socket->protocol.package_length_size = SW_WEBSOCKET_HEADER_LEN;
+        socket->protocol.package_length_offset = 0;
+        socket->protocol.package_body_offset = 0;
+        socket->protocol.get_package_length = swWebSocket_get_package_length;
     }
     // handler keep alive
     if (!keep_alive && !websocket)
@@ -1742,8 +1766,8 @@ static PHP_METHOD(swoole_http_client_coro, __construct)
     ZEND_PARSE_PARAMETERS_END_EX(RETURN_FALSE);
 
     zend_update_property_stringl(swoole_http_client_coro_ce, ZEND_THIS, ZEND_STRL("host"), host, host_len);
-    zend_update_property_long(swoole_http_client_coro_ce,ZEND_THIS, ZEND_STRL("port"), port);
-    zend_update_property_bool(swoole_http_client_coro_ce,ZEND_THIS, ZEND_STRL("ssl"), ssl);
+    zend_update_property_long(swoole_http_client_coro_ce, ZEND_THIS, ZEND_STRL("port"), port);
+    zend_update_property_bool(swoole_http_client_coro_ce, ZEND_THIS, ZEND_STRL("ssl"), ssl);
     // check host
     if (host_len == 0)
     {
@@ -1830,7 +1854,7 @@ static PHP_METHOD(swoole_http_client_coro, setHeaders)
     zval *headers;
 
     ZEND_PARSE_PARAMETERS_START(1, 1)
-        Z_PARAM_ARRAY(headers)
+        Z_PARAM_ARRAY_EX(headers, 0, 1)
     ZEND_PARSE_PARAMETERS_END_EX(RETURN_FALSE);
 
     zend_update_property(swoole_http_client_coro_ce, ZEND_THIS, ZEND_STRL("requestHeaders"), headers);
