@@ -721,8 +721,8 @@ static int multipart_body_on_data(multipart_parser* p, const char *at, size_t le
 #if 0
 static void get_random_file_name(char *des, const char *src)
 {
-    unsigned char digest[16] = {0};
-    char buf[19] = {0};
+    unsigned char digest[16] = {};
+    char buf[19] = {};
     int n = sprintf(buf, "%s%d", src, swoole_system_random(0, 9999));
 
     PHP_MD5_CTX ctx;
@@ -866,30 +866,32 @@ static int multipart_body_on_data_end(multipart_parser* p)
 
 static int http_request_on_body(swoole_http_parser *parser, const char *at, size_t length)
 {
-    http_context *ctx = (http_context *) parser->data;
-
-    if (ctx->recv_chunked)
+    if (length == 0)
     {
-        if (length != 0)
-        {
-            if (ctx->request.chunked_body == nullptr)
-            {
-                ctx->request.chunked_body = swString_new(SW_BUFFER_SIZE_STD);
-                if (ctx->request.chunked_body == nullptr)
-                {
-                    return -1;
-                }
-            }
-            swString_append_ptr(ctx->request.chunked_body, at, length);
-        }
         return 0;
     }
 
-    ctx->request.body_length = length;
+    http_context *ctx = (http_context *) parser->data;
+    bool is_beginning =  (ctx->request.chunked_body ? ctx->request.chunked_body->length : ctx->request.body_length) == 0;
 
-    swTraceLog(SW_TRACE_HTTP, "request body_length=%ld", length);
+    if (ctx->recv_chunked)
+    {
+        if (ctx->request.chunked_body == nullptr)
+        {
+            ctx->request.chunked_body = swString_new(SW_BUFFER_SIZE_STD);
+            if (ctx->request.chunked_body == nullptr)
+            {
+                return -1;
+            }
+        }
+        swString_append_ptr(ctx->request.chunked_body, at, length);
+    }
+    else
+    {
+        ctx->request.body_length += length;
+    }
 
-    if (ctx->parse_body && ctx->request.post_form_urlencoded)
+    if (!ctx->recv_chunked && ctx->parse_body && ctx->request.post_form_urlencoded)
     {
         sapi_module.treat_data(
             PARSE_STRING,
@@ -900,13 +902,20 @@ static int http_request_on_body(swoole_http_parser *parser, const char *at, size
     else if (ctx->mt_parser != NULL)
     {
         multipart_parser *multipart_parser = ctx->mt_parser;
-        char *c = (char *) at;
-        while (*c == '\r' && *(c + 1) == '\n')
+        if (is_beginning)
         {
-            c += 2;
-            length -= 2;
+            /* Compatibility: some clients may send extra EOL */
+            do
+            {
+                if (*at != '\r' && *at != '\n')
+                {
+                    break;
+                }
+                at++;
+                length--;
+            } while (length != 0);
         }
-        size_t n = multipart_parser_execute(multipart_parser, c, length);
+        size_t n = multipart_parser_execute(multipart_parser, at, length);
         if (n != length)
         {
             swoole_error_log(SW_LOG_WARNING, SW_ERROR_SERVER_INVALID_REQUEST, "parse multipart body failed, n=%zu", n);
@@ -919,6 +928,17 @@ static int http_request_on_body(swoole_http_parser *parser, const char *at, size
 static int http_request_message_complete(swoole_http_parser *parser)
 {
     http_context *ctx = (http_context *) parser->data;
+    size_t content_length =  ctx->request.chunked_body ? ctx->request.chunked_body->length : ctx->request.body_length;
+
+    if (ctx->request.chunked_body != nullptr && ctx->parse_body && ctx->request.post_form_urlencoded)
+    {
+        /* parse dechunked content */
+        sapi_module.treat_data(
+            PARSE_STRING,
+            estrndup(ctx->request.chunked_body->str, content_length), // do not free, it will be freed by treat_data
+            swoole_http_init_and_read_property(swoole_http_request_ce, ctx->request.zobject, &ctx->request.zpost, ZEND_STRL("post"))
+        );
+    }
     if (ctx->mt_parser)
     {
         multipart_parser_free(ctx->mt_parser);
@@ -926,6 +946,8 @@ static int http_request_message_complete(swoole_http_parser *parser)
     }
     ctx->completed = 1;
 
+    swTraceLog(SW_TRACE_HTTP, "request body length=%ld", content_length);
+
     return 1; /* return from execute */
 }
 
