@@ -123,7 +123,7 @@ static void php_swoole_http_response_free_object(zend_object *object)
 
     if (ctx)
     {
-        if (!ctx->end && !ctx->detached)
+        if (!ctx->end && !ctx->detached && sw_reactor())
         {
             if (ctx->response.status == 0)
             {
@@ -588,7 +588,7 @@ int swoole_http_response_compress(swString *body, int method, int level)
     {
         if (level < BROTLI_MIN_QUALITY)
         {
-            level = BROTLI_MAX_QUALITY;
+            level = BROTLI_MIN_QUALITY;
         }
         else if (level > BROTLI_MAX_QUALITY)
         {
@@ -630,10 +630,14 @@ int swoole_http_response_compress(swString *body, int method, int level)
         return SW_ERR;
     }
 #ifdef SW_HAVE_ZLIB
-    if (level == Z_NO_COMPRESSION)
+    if (level < Z_NO_COMPRESSION)
     {
         level = Z_DEFAULT_COMPRESSION;
     }
+    else if (level == Z_NO_COMPRESSION)
+    {
+        level = Z_BEST_SPEED;
+    }
     else if (level > Z_BEST_COMPRESSION)
     {
         level = Z_BEST_COMPRESSION;
@@ -648,7 +652,7 @@ int swoole_http_response_compress(swString *body, int method, int level)
         }
     }
 
-    z_stream zstream = { 0 };
+    z_stream zstream = {};
     int status;
 
     zstream.zalloc = php_zlib_alloc;
@@ -854,11 +858,6 @@ bool swoole_http_response_set_header(http_context *ctx, const char *k, size_t kl
         php_swoole_error(E_WARNING, "header key is too long");
         return false;
     }
-    if (UNEXPECTED(vlen > SW_HTTP_HEADER_VALUE_SIZE - 1))
-    {
-        php_swoole_error(E_WARNING, "header value is too long");
-        return false;
-    }
     zval *zheader = swoole_http_init_and_read_property(swoole_http_response_ce, ctx->response.zobject, &ctx->response.zheader, ZEND_STRL("header"));
     if (ucwords)
     {
@@ -1183,11 +1182,6 @@ static PHP_METHOD(swoole_http_response, trailer)
         php_swoole_error(E_WARNING, "trailer key is too long");
         RETURN_FALSE;
     }
-    if (UNEXPECTED(vlen > SW_HTTP_HEADER_VALUE_SIZE - 1))
-    {
-        php_swoole_error(E_WARNING, "trailer value is too long");
-        RETURN_FALSE;
-    }
     zval *ztrailer = swoole_http_init_and_read_property(swoole_http_response_ce, ctx->response.zobject, &ctx->response.ztrailer, ZEND_STRL("trailer"));
     strncpy(key_buf, k, klen)[klen] = '\0';
     swoole_strtolower(key_buf, klen);
