@@ -158,8 +158,10 @@ public:
         swHttp2_send_setting_frame(&sock->protocol, sock->socket);
 
         sock->open_length_check = true;
-        sock->protocol.get_package_length = swHttp2_get_frame_length;
         sock->protocol.package_length_size = SW_HTTP2_FRAME_HEADER_SIZE;
+        sock->protocol.package_length_offset = 0;
+        sock->protocol.package_body_offset = 0;
+        sock->protocol.get_package_length = swHttp2_get_frame_length;
 
         http2_session session(ctx->fd);
         session.default_ctx = ctx;
@@ -177,6 +179,9 @@ public:
             swoole_http2_server_parse(&session, buffer->str);
         }
 
+        /* default_ctx does not blong to session object */
+        session.default_ctx = nullptr;
+
         ctx->detached = 1;
         zval_dtor(ctx->request.zobject);
         zval_dtor(ctx->response.zobject);
@@ -459,7 +464,7 @@ static PHP_METHOD(swoole_http_server_coro, start)
             {
                 _wait_1s: System::sleep(SW_ACCEPT_RETRY_TIME);
             }
-            else if (sock->errCode == ETIMEDOUT)
+            else if (sock->errCode == ETIMEDOUT || sock->errCode == SW_ERROR_SSL_BAD_CLIENT)
             {
                 continue;
             }
@@ -594,14 +599,11 @@ static PHP_METHOD(swoole_http_server_coro, onAccept)
 
         zval *zserver = ctx->request.zserver;
         add_assoc_long(zserver, "server_port", hs->socket->get_bind_port());
-        add_assoc_long(zserver, "remote_port", (zend_long) hs->socket->get_port());
-        add_assoc_string(zserver, "remote_addr", (char *) hs->socket->get_ip());
+        add_assoc_long(zserver, "remote_port", (zend_long) sock->get_port());
+        add_assoc_string(zserver, "remote_addr", (char *) sock->get_ip());
 
         php_swoole_fci *fci = hs->get_handler(ctx);
-        zval args[2];
-        args[0] = *ctx->request.zobject;
-        args[1] = *ctx->response.zobject;
-
+        zval args[2] = { *ctx->request.zobject, *ctx->response.zobject };
         bool keep_alive = swoole_http_should_keep_alive(&ctx->parser) && !ctx->websocket;
 
         if (fci)
@@ -660,13 +662,21 @@ static void http2_server_onRequest(http2_session *session, http2_stream *stream)
     add_assoc_string(zserver, "server_protocol", (char * ) "HTTP/2");
 
     php_swoole_fci *fci = hs->get_handler(ctx);
+    zval args[2] = { *ctx->request.zobject, *ctx->response.zobject };
 
-    zval args[2] = {*ctx->request.zobject, *ctx->response.zobject};
-    if (UNEXPECTED(!zend::function::call(&fci->fci_cache, 2, args, NULL, SwooleG.enable_coroutine)))
+    if (fci)
     {
-        stream->reset(SW_HTTP2_ERROR_INTERNAL_ERROR);
-        php_swoole_error(E_WARNING, "%s->onRequest[v2] handler error", ZSTR_VAL(swoole_http_server_ce->name));
+        if (UNEXPECTED(!zend::function::call(&fci->fci_cache, 2, args, NULL, SwooleG.enable_coroutine)))
+        {
+            stream->reset(SW_HTTP2_ERROR_INTERNAL_ERROR);
+            php_swoole_error(E_WARNING, "%s->onRequest[v2] handler error", ZSTR_VAL(swoole_http_server_ce->name));
+        }
     }
+    else
+    {
+        ctx->response.status = SW_HTTP_NOT_FOUND;
+    }
+
     zval_ptr_dtor(&args[0]);
     zval_ptr_dtor(&args[1]);
 }
