@@ -207,11 +207,13 @@ struct real_func
 
 void php_swoole_runtime_rshutdown()
 {
-    if (!function_table)
+    if (!hook_init)
     {
         return;
     }
 
+    hook_init = false;
+
     void *ptr;
     ZEND_HASH_FOREACH_PTR(function_table, ptr)
     {
@@ -1037,16 +1039,6 @@ static php_stream *socket_create(
     return stream;
 }
 
-static void init_function()
-{
-    if (function_table)
-    {
-        return;
-    }
-    function_table = (zend_array*) emalloc(sizeof(zend_array));
-    zend_hash_init(function_table, 8, NULL, NULL, 0);
-}
-
 bool PHPCoroutine::enable_hook(int flags)
 {
     if (sw_unlikely(enable_strict_mode))
@@ -1068,7 +1060,8 @@ bool PHPCoroutine::enable_hook(int flags)
         // file
         memcpy((void*) &ori_php_plain_files_wrapper, &php_plain_files_wrapper, sizeof(php_plain_files_wrapper));
 
-        init_function();
+        function_table = (zend_array*) emalloc(sizeof(zend_array));
+        zend_hash_init(function_table, 8, NULL, NULL, 0);
 
         hook_init = true;
     }
@@ -1155,7 +1148,11 @@ bool PHPCoroutine::enable_hook(int flags)
     {
         if (hook_flags & SW_HOOK_SSL)
         {
-            php_stream_xport_register("ssl", ori_factory.ssl);
+            if (ori_factory.ssl != nullptr) {
+                php_stream_xport_register("ssl", ori_factory.ssl);
+            } else {
+                php_stream_xport_unregister("ssl");
+            }
         }
     }
     if (flags & SW_HOOK_TLS)
@@ -1172,7 +1169,11 @@ bool PHPCoroutine::enable_hook(int flags)
     {
         if (hook_flags & SW_HOOK_TLS)
         {
-            php_stream_xport_register("tls", ori_factory.tls);
+            if (ori_factory.tls != nullptr) {
+                php_stream_xport_register("tls", ori_factory.tls);
+            } else {
+                php_stream_xport_unregister("tls");
+            }
         }
     }
     if (flags & SW_HOOK_STREAM_FUNCTION)
@@ -1305,12 +1306,6 @@ bool PHPCoroutine::enable_hook(int flags)
     return true;
 }
 
-bool PHPCoroutine::inject_function()
-{
-    init_function();
-    return true;
-}
-
 bool PHPCoroutine::disable_hook()
 {
     return enable_hook(0);
@@ -1843,7 +1838,7 @@ static PHP_FUNCTION(swoole_user_func_handler)
     zend_fcall_info fci;
     fci.size = sizeof(fci);
     fci.object = NULL;
-    fci.function_name = {{0}};
+    fci.function_name = {};
     fci.retval = return_value;
     fci.param_count = ZEND_NUM_ARGS();
     fci.params = ZEND_CALL_ARG(execute_data, 1);
