@@ -738,8 +738,8 @@ static void swoole_socket_coro_register_constants(int module_number)
 #if HAVE_AI_IDN
     REGISTER_LONG_CONSTANT("AI_IDN", AI_IDN, CONST_CS | CONST_PERSISTENT);
     REGISTER_LONG_CONSTANT("AI_CANONIDN", AI_CANONIDN, CONST_CS | CONST_PERSISTENT);
-    REGISTER_LONG_CONSTANT("AI_IDN_ALLOW_UNASSIGNED", AI_IDN_ALLOW_UNASSIGNED, CONST_CS | CONST_PERSISTENT);
-    REGISTER_LONG_CONSTANT("AI_IDN_USE_STD3_ASCII_RULES", AI_IDN_USE_STD3_ASCII_RULES, CONST_CS | CONST_PERSISTENT);
+    // REGISTER_LONG_CONSTANT("AI_IDN_ALLOW_UNASSIGNED", AI_IDN_ALLOW_UNASSIGNED, CONST_CS | CONST_PERSISTENT);
+    // REGISTER_LONG_CONSTANT("AI_IDN_USE_STD3_ASCII_RULES", AI_IDN_USE_STD3_ASCII_RULES, CONST_CS | CONST_PERSISTENT);
 #endif
 #ifdef AI_NUMERICSERV
     REGISTER_LONG_CONSTANT("AI_NUMERICSERV", AI_NUMERICSERV, CONST_CS | CONST_PERSISTENT);
@@ -904,6 +904,9 @@ SW_API bool php_swoole_socket_set_protocol(Socket *sock, zval *zset)
     if (php_swoole_array_get_value(vht, "open_mqtt_protocol", ztmp))
     {
         sock->open_length_check = zval_is_true(ztmp);
+        sock->protocol.package_length_size = SW_MQTT_MIN_LENGTH;
+        sock->protocol.package_length_offset = 0;
+        sock->protocol.package_body_offset = 0;
         sock->protocol.get_package_length = swMqtt_get_package_length;
     }
     // open length check
@@ -1362,6 +1365,12 @@ static PHP_METHOD(swoole_socket_coro, close)
     {
         RETURN_FALSE;
     }
+    if (sock->socket->protocol.private_data)
+    {
+        zend_fcall_info_cache *package_length_func = (zend_fcall_info_cache *) sock->socket->protocol.private_data;
+        sw_zend_fci_cache_discard(package_length_func);
+        efree(package_length_func);
+    }
     if (sock->socket->close())
     {
         delete sock->socket;
@@ -1374,30 +1383,32 @@ static PHP_METHOD(swoole_socket_coro, getsockname)
 {
     swoole_get_socket_coro(sock, ZEND_THIS);
 
-    if (!sock->socket->getsockname())
+    swSocketAddress sa;
+    if (!sock->socket->getsockname(&sa))
     {
         swoole_socket_coro_sync_properties(ZEND_THIS, sock);
         RETURN_FALSE;
     }
 
     array_init(return_value);
-    add_assoc_string(return_value, "address", (char *) sock->socket->get_ip());
-    add_assoc_long(return_value, "port", sock->socket->get_port());
+    add_assoc_string(return_value, "address", (char *) swConnection_get_ip(sock->socket->get_type(), &sa));
+    add_assoc_long(return_value, "port", swConnection_get_port(sock->socket->get_type(), &sa));
 }
 
 static PHP_METHOD(swoole_socket_coro, getpeername)
 {
     swoole_get_socket_coro(sock, ZEND_THIS);
 
-    if (!sock->socket->getpeername())
+    swSocketAddress sa;
+    if (!sock->socket->getpeername(&sa))
     {
         swoole_socket_coro_sync_properties(ZEND_THIS, sock);
         RETURN_FALSE;
     }
 
     array_init(return_value);
-    add_assoc_string(return_value, "address", (char *) sock->socket->get_ip());
-    add_assoc_long(return_value, "port", sock->socket->get_port());
+    add_assoc_string(return_value, "address", (char *) swConnection_get_ip(sock->socket->get_type(), &sa));
+    add_assoc_long(return_value, "port", swConnection_get_port(sock->socket->get_type(), &sa));
 }
 
 static PHP_METHOD(swoole_socket_coro, getOption)
