@@ -32,7 +32,7 @@ class_alias(SwooleTest\ServerManager::class, ServerManager::class);
 class_alias(SwooleTest\RandStr::class, RandStr::class);
 class_alias(SwooleTest\TcpStat::class, TcpStat::class);
 
-class Assert extends Swoole\Assert
+class Assert extends SwooleTest\Assert
 {
     protected static $throwException = false;
 }
