@@ -1,5 +1,6 @@
+#!/usr/bin/env php
 <?php
-$fp = fopen(__DIR__ . "/a.txt", "w");
+$fp = fopen(__DIR__ . "/test.txt", "w");
 ftruncate($fp, filesize(__DIR__ . "/a.txt"));
 fwrite($fp, str_repeat('A', 1024));
 fwrite($fp, str_repeat('B', 1024));
